// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v3.11.4
// source: github.com/moby/buildkit/frontend/gateway/pb/gateway.proto

package moby_buildkit_v1_frontend

import (
	types1 "github.com/moby/buildkit/api/types"
	pb "github.com/moby/buildkit/solver/pb"
	pb1 "github.com/moby/buildkit/sourcepolicy/pb"
	pb2 "github.com/moby/buildkit/util/apicaps/pb"
	types "github.com/tonistiigi/fsutil/types"
	status "google.golang.org/genproto/googleapis/rpc/status"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type AttestationKind int32

const (
	AttestationKind_InToto AttestationKind = 0
	AttestationKind_Bundle AttestationKind = 1
)

// Enum value maps for AttestationKind.
var (
	AttestationKind_name = map[int32]string{
		0: "InToto",
		1: "Bundle",
	}
	AttestationKind_value = map[string]int32{
		"InToto": 0,
		"Bundle": 1,
	}
)

func (x AttestationKind) Enum() *AttestationKind {
	p := new(AttestationKind)
	*p = x
	return p
}

func (x AttestationKind) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (AttestationKind) Descriptor() protoreflect.EnumDescriptor {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes[0].Descriptor()
}

func (AttestationKind) Type() protoreflect.EnumType {
	return &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes[0]
}

func (x AttestationKind) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use AttestationKind.Descriptor instead.
func (AttestationKind) EnumDescriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{0}
}

type InTotoSubjectKind int32

const (
	InTotoSubjectKind_Self InTotoSubjectKind = 0
	InTotoSubjectKind_Raw  InTotoSubjectKind = 1
)

// Enum value maps for InTotoSubjectKind.
var (
	InTotoSubjectKind_name = map[int32]string{
		0: "Self",
		1: "Raw",
	}
	InTotoSubjectKind_value = map[string]int32{
		"Self": 0,
		"Raw":  1,
	}
)

func (x InTotoSubjectKind) Enum() *InTotoSubjectKind {
	p := new(InTotoSubjectKind)
	*p = x
	return p
}

func (x InTotoSubjectKind) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (InTotoSubjectKind) Descriptor() protoreflect.EnumDescriptor {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes[1].Descriptor()
}

func (InTotoSubjectKind) Type() protoreflect.EnumType {
	return &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes[1]
}

func (x InTotoSubjectKind) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use InTotoSubjectKind.Descriptor instead.
func (InTotoSubjectKind) EnumDescriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{1}
}

type Result struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Result:
	//
	//	*Result_RefDeprecated
	//	*Result_RefsDeprecated
	//	*Result_Ref
	//	*Result_Refs
	Result   isResult_Result   `protobuf_oneof:"result"`
	Metadata map[string][]byte `protobuf:"bytes,10,rep,name=metadata,proto3" json:"metadata,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// 11 was used during development and is reserved for old attestation format
	Attestations  map[string]*Attestations `protobuf:"bytes,12,rep,name=attestations,proto3" json:"attestations,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Result) Reset() {
	*x = Result{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Result) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Result) ProtoMessage() {}

func (x *Result) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Result.ProtoReflect.Descriptor instead.
func (*Result) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{0}
}

func (x *Result) GetResult() isResult_Result {
	if x != nil {
		return x.Result
	}
	return nil
}

func (x *Result) GetRefDeprecated() string {
	if x != nil {
		if x, ok := x.Result.(*Result_RefDeprecated); ok {
			return x.RefDeprecated
		}
	}
	return ""
}

func (x *Result) GetRefsDeprecated() *RefMapDeprecated {
	if x != nil {
		if x, ok := x.Result.(*Result_RefsDeprecated); ok {
			return x.RefsDeprecated
		}
	}
	return nil
}

func (x *Result) GetRef() *Ref {
	if x != nil {
		if x, ok := x.Result.(*Result_Ref); ok {
			return x.Ref
		}
	}
	return nil
}

func (x *Result) GetRefs() *RefMap {
	if x != nil {
		if x, ok := x.Result.(*Result_Refs); ok {
			return x.Refs
		}
	}
	return nil
}

func (x *Result) GetMetadata() map[string][]byte {
	if x != nil {
		return x.Metadata
	}
	return nil
}

func (x *Result) GetAttestations() map[string]*Attestations {
	if x != nil {
		return x.Attestations
	}
	return nil
}

type isResult_Result interface {
	isResult_Result()
}

type Result_RefDeprecated struct {
	// Deprecated non-array refs.
	RefDeprecated string `protobuf:"bytes,1,opt,name=refDeprecated,proto3,oneof"`
}

type Result_RefsDeprecated struct {
	RefsDeprecated *RefMapDeprecated `protobuf:"bytes,2,opt,name=refsDeprecated,proto3,oneof"`
}

type Result_Ref struct {
	Ref *Ref `protobuf:"bytes,3,opt,name=ref,proto3,oneof"`
}

type Result_Refs struct {
	Refs *RefMap `protobuf:"bytes,4,opt,name=refs,proto3,oneof"`
}

func (*Result_RefDeprecated) isResult_Result() {}

func (*Result_RefsDeprecated) isResult_Result() {}

func (*Result_Ref) isResult_Result() {}

func (*Result_Refs) isResult_Result() {}

type RefMapDeprecated struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Refs          map[string]string      `protobuf:"bytes,1,rep,name=refs,proto3" json:"refs,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RefMapDeprecated) Reset() {
	*x = RefMapDeprecated{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RefMapDeprecated) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RefMapDeprecated) ProtoMessage() {}

func (x *RefMapDeprecated) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RefMapDeprecated.ProtoReflect.Descriptor instead.
func (*RefMapDeprecated) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{1}
}

func (x *RefMapDeprecated) GetRefs() map[string]string {
	if x != nil {
		return x.Refs
	}
	return nil
}

type Ref struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Def           *pb.Definition         `protobuf:"bytes,2,opt,name=def,proto3" json:"def,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Ref) Reset() {
	*x = Ref{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Ref) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Ref) ProtoMessage() {}

func (x *Ref) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Ref.ProtoReflect.Descriptor instead.
func (*Ref) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{2}
}

func (x *Ref) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *Ref) GetDef() *pb.Definition {
	if x != nil {
		return x.Def
	}
	return nil
}

type RefMap struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Refs          map[string]*Ref        `protobuf:"bytes,1,rep,name=refs,proto3" json:"refs,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RefMap) Reset() {
	*x = RefMap{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RefMap) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RefMap) ProtoMessage() {}

func (x *RefMap) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RefMap.ProtoReflect.Descriptor instead.
func (*RefMap) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{3}
}

func (x *RefMap) GetRefs() map[string]*Ref {
	if x != nil {
		return x.Refs
	}
	return nil
}

type Attestations struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Attestation   []*Attestation         `protobuf:"bytes,1,rep,name=attestation,proto3" json:"attestation,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Attestations) Reset() {
	*x = Attestations{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Attestations) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Attestations) ProtoMessage() {}

func (x *Attestations) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Attestations.ProtoReflect.Descriptor instead.
func (*Attestations) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{4}
}

func (x *Attestations) GetAttestation() []*Attestation {
	if x != nil {
		return x.Attestation
	}
	return nil
}

type Attestation struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	Kind                AttestationKind        `protobuf:"varint,1,opt,name=kind,proto3,enum=moby.buildkit.v1.frontend.AttestationKind" json:"kind,omitempty"`
	Metadata            map[string][]byte      `protobuf:"bytes,2,rep,name=metadata,proto3" json:"metadata,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	Ref                 *Ref                   `protobuf:"bytes,3,opt,name=ref,proto3" json:"ref,omitempty"`
	Path                string                 `protobuf:"bytes,4,opt,name=path,proto3" json:"path,omitempty"`
	InTotoPredicateType string                 `protobuf:"bytes,5,opt,name=inTotoPredicateType,proto3" json:"inTotoPredicateType,omitempty"`
	InTotoSubjects      []*InTotoSubject       `protobuf:"bytes,6,rep,name=inTotoSubjects,proto3" json:"inTotoSubjects,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *Attestation) Reset() {
	*x = Attestation{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Attestation) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Attestation) ProtoMessage() {}

func (x *Attestation) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Attestation.ProtoReflect.Descriptor instead.
func (*Attestation) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{5}
}

func (x *Attestation) GetKind() AttestationKind {
	if x != nil {
		return x.Kind
	}
	return AttestationKind_InToto
}

func (x *Attestation) GetMetadata() map[string][]byte {
	if x != nil {
		return x.Metadata
	}
	return nil
}

func (x *Attestation) GetRef() *Ref {
	if x != nil {
		return x.Ref
	}
	return nil
}

func (x *Attestation) GetPath() string {
	if x != nil {
		return x.Path
	}
	return ""
}

func (x *Attestation) GetInTotoPredicateType() string {
	if x != nil {
		return x.InTotoPredicateType
	}
	return ""
}

func (x *Attestation) GetInTotoSubjects() []*InTotoSubject {
	if x != nil {
		return x.InTotoSubjects
	}
	return nil
}

type InTotoSubject struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Kind          InTotoSubjectKind      `protobuf:"varint,1,opt,name=kind,proto3,enum=moby.buildkit.v1.frontend.InTotoSubjectKind" json:"kind,omitempty"`
	Digest        []string               `protobuf:"bytes,2,rep,name=digest,proto3" json:"digest,omitempty"`
	Name          string                 `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *InTotoSubject) Reset() {
	*x = InTotoSubject{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *InTotoSubject) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*InTotoSubject) ProtoMessage() {}

func (x *InTotoSubject) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use InTotoSubject.ProtoReflect.Descriptor instead.
func (*InTotoSubject) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{6}
}

func (x *InTotoSubject) GetKind() InTotoSubjectKind {
	if x != nil {
		return x.Kind
	}
	return InTotoSubjectKind_Self
}

func (x *InTotoSubject) GetDigest() []string {
	if x != nil {
		return x.Digest
	}
	return nil
}

func (x *InTotoSubject) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

type ReturnRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Result        *Result                `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	Error         *status.Status         `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReturnRequest) Reset() {
	*x = ReturnRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReturnRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReturnRequest) ProtoMessage() {}

func (x *ReturnRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReturnRequest.ProtoReflect.Descriptor instead.
func (*ReturnRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{7}
}

func (x *ReturnRequest) GetResult() *Result {
	if x != nil {
		return x.Result
	}
	return nil
}

func (x *ReturnRequest) GetError() *status.Status {
	if x != nil {
		return x.Error
	}
	return nil
}

type ReturnResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReturnResponse) Reset() {
	*x = ReturnResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReturnResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReturnResponse) ProtoMessage() {}

func (x *ReturnResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReturnResponse.ProtoReflect.Descriptor instead.
func (*ReturnResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{8}
}

type InputsRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *InputsRequest) Reset() {
	*x = InputsRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *InputsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*InputsRequest) ProtoMessage() {}

func (x *InputsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use InputsRequest.ProtoReflect.Descriptor instead.
func (*InputsRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{9}
}

type InputsResponse struct {
	state         protoimpl.MessageState    `protogen:"open.v1"`
	Definitions   map[string]*pb.Definition `protobuf:"bytes,1,rep,name=Definitions,proto3" json:"Definitions,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *InputsResponse) Reset() {
	*x = InputsResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *InputsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*InputsResponse) ProtoMessage() {}

func (x *InputsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use InputsResponse.ProtoReflect.Descriptor instead.
func (*InputsResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{10}
}

func (x *InputsResponse) GetDefinitions() map[string]*pb.Definition {
	if x != nil {
		return x.Definitions
	}
	return nil
}

type ResolveImageConfigRequest struct {
	state          protoimpl.MessageState `protogen:"open.v1"`
	Ref            string                 `protobuf:"bytes,1,opt,name=Ref,proto3" json:"Ref,omitempty"`
	Platform       *pb.Platform           `protobuf:"bytes,2,opt,name=Platform,proto3" json:"Platform,omitempty"`
	ResolveMode    string                 `protobuf:"bytes,3,opt,name=ResolveMode,proto3" json:"ResolveMode,omitempty"`
	LogName        string                 `protobuf:"bytes,4,opt,name=LogName,proto3" json:"LogName,omitempty"`
	ResolverType   int32                  `protobuf:"varint,5,opt,name=ResolverType,proto3" json:"ResolverType,omitempty"`
	SessionID      string                 `protobuf:"bytes,6,opt,name=SessionID,proto3" json:"SessionID,omitempty"`
	StoreID        string                 `protobuf:"bytes,7,opt,name=StoreID,proto3" json:"StoreID,omitempty"`
	SourcePolicies []*pb1.Policy          `protobuf:"bytes,8,rep,name=SourcePolicies,proto3" json:"SourcePolicies,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *ResolveImageConfigRequest) Reset() {
	*x = ResolveImageConfigRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveImageConfigRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveImageConfigRequest) ProtoMessage() {}

func (x *ResolveImageConfigRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveImageConfigRequest.ProtoReflect.Descriptor instead.
func (*ResolveImageConfigRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{11}
}

func (x *ResolveImageConfigRequest) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

func (x *ResolveImageConfigRequest) GetPlatform() *pb.Platform {
	if x != nil {
		return x.Platform
	}
	return nil
}

func (x *ResolveImageConfigRequest) GetResolveMode() string {
	if x != nil {
		return x.ResolveMode
	}
	return ""
}

func (x *ResolveImageConfigRequest) GetLogName() string {
	if x != nil {
		return x.LogName
	}
	return ""
}

func (x *ResolveImageConfigRequest) GetResolverType() int32 {
	if x != nil {
		return x.ResolverType
	}
	return 0
}

func (x *ResolveImageConfigRequest) GetSessionID() string {
	if x != nil {
		return x.SessionID
	}
	return ""
}

func (x *ResolveImageConfigRequest) GetStoreID() string {
	if x != nil {
		return x.StoreID
	}
	return ""
}

func (x *ResolveImageConfigRequest) GetSourcePolicies() []*pb1.Policy {
	if x != nil {
		return x.SourcePolicies
	}
	return nil
}

type ResolveImageConfigResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Digest        string                 `protobuf:"bytes,1,opt,name=Digest,proto3" json:"Digest,omitempty"`
	Config        []byte                 `protobuf:"bytes,2,opt,name=Config,proto3" json:"Config,omitempty"`
	Ref           string                 `protobuf:"bytes,3,opt,name=Ref,proto3" json:"Ref,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResolveImageConfigResponse) Reset() {
	*x = ResolveImageConfigResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveImageConfigResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveImageConfigResponse) ProtoMessage() {}

func (x *ResolveImageConfigResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveImageConfigResponse.ProtoReflect.Descriptor instead.
func (*ResolveImageConfigResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{12}
}

func (x *ResolveImageConfigResponse) GetDigest() string {
	if x != nil {
		return x.Digest
	}
	return ""
}

func (x *ResolveImageConfigResponse) GetConfig() []byte {
	if x != nil {
		return x.Config
	}
	return nil
}

func (x *ResolveImageConfigResponse) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

type ResolveSourceMetaRequest struct {
	state          protoimpl.MessageState `protogen:"open.v1"`
	Source         *pb.SourceOp           `protobuf:"bytes,1,opt,name=Source,proto3" json:"Source,omitempty"`
	Platform       *pb.Platform           `protobuf:"bytes,2,opt,name=Platform,proto3" json:"Platform,omitempty"`
	LogName        string                 `protobuf:"bytes,3,opt,name=LogName,proto3" json:"LogName,omitempty"`
	ResolveMode    string                 `protobuf:"bytes,4,opt,name=ResolveMode,proto3" json:"ResolveMode,omitempty"`
	SourcePolicies []*pb1.Policy          `protobuf:"bytes,8,rep,name=SourcePolicies,proto3" json:"SourcePolicies,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *ResolveSourceMetaRequest) Reset() {
	*x = ResolveSourceMetaRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveSourceMetaRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveSourceMetaRequest) ProtoMessage() {}

func (x *ResolveSourceMetaRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveSourceMetaRequest.ProtoReflect.Descriptor instead.
func (*ResolveSourceMetaRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{13}
}

func (x *ResolveSourceMetaRequest) GetSource() *pb.SourceOp {
	if x != nil {
		return x.Source
	}
	return nil
}

func (x *ResolveSourceMetaRequest) GetPlatform() *pb.Platform {
	if x != nil {
		return x.Platform
	}
	return nil
}

func (x *ResolveSourceMetaRequest) GetLogName() string {
	if x != nil {
		return x.LogName
	}
	return ""
}

func (x *ResolveSourceMetaRequest) GetResolveMode() string {
	if x != nil {
		return x.ResolveMode
	}
	return ""
}

func (x *ResolveSourceMetaRequest) GetSourcePolicies() []*pb1.Policy {
	if x != nil {
		return x.SourcePolicies
	}
	return nil
}

type ResolveSourceMetaResponse struct {
	state         protoimpl.MessageState      `protogen:"open.v1"`
	Source        *pb.SourceOp                `protobuf:"bytes,1,opt,name=Source,proto3" json:"Source,omitempty"`
	Image         *ResolveSourceImageResponse `protobuf:"bytes,2,opt,name=Image,proto3" json:"Image,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResolveSourceMetaResponse) Reset() {
	*x = ResolveSourceMetaResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveSourceMetaResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveSourceMetaResponse) ProtoMessage() {}

func (x *ResolveSourceMetaResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveSourceMetaResponse.ProtoReflect.Descriptor instead.
func (*ResolveSourceMetaResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{14}
}

func (x *ResolveSourceMetaResponse) GetSource() *pb.SourceOp {
	if x != nil {
		return x.Source
	}
	return nil
}

func (x *ResolveSourceMetaResponse) GetImage() *ResolveSourceImageResponse {
	if x != nil {
		return x.Image
	}
	return nil
}

type ResolveSourceImageResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Digest        string                 `protobuf:"bytes,1,opt,name=Digest,proto3" json:"Digest,omitempty"`
	Config        []byte                 `protobuf:"bytes,2,opt,name=Config,proto3" json:"Config,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResolveSourceImageResponse) Reset() {
	*x = ResolveSourceImageResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveSourceImageResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveSourceImageResponse) ProtoMessage() {}

func (x *ResolveSourceImageResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveSourceImageResponse.ProtoReflect.Descriptor instead.
func (*ResolveSourceImageResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{15}
}

func (x *ResolveSourceImageResponse) GetDigest() string {
	if x != nil {
		return x.Digest
	}
	return ""
}

func (x *ResolveSourceImageResponse) GetConfig() []byte {
	if x != nil {
		return x.Config
	}
	return nil
}

type SolveRequest struct {
	state       protoimpl.MessageState `protogen:"open.v1"`
	Definition  *pb.Definition         `protobuf:"bytes,1,opt,name=Definition,proto3" json:"Definition,omitempty"`
	Frontend    string                 `protobuf:"bytes,2,opt,name=Frontend,proto3" json:"Frontend,omitempty"`
	FrontendOpt map[string]string      `protobuf:"bytes,3,rep,name=FrontendOpt,proto3" json:"FrontendOpt,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// 4 was removed in BuildKit v0.11.0.
	AllowResultReturn   bool `protobuf:"varint,5,opt,name=allowResultReturn,proto3" json:"allowResultReturn,omitempty"`
	AllowResultArrayRef bool `protobuf:"varint,6,opt,name=allowResultArrayRef,proto3" json:"allowResultArrayRef,omitempty"`
	// apicaps.CapSolveInlineReturn deprecated
	Final        bool   `protobuf:"varint,10,opt,name=Final,proto3" json:"Final,omitempty"`
	ExporterAttr []byte `protobuf:"bytes,11,opt,name=ExporterAttr,proto3" json:"ExporterAttr,omitempty"`
	// CacheImports was added in BuildKit v0.4.0.
	// apicaps:CapImportCaches
	CacheImports []*CacheOptionsEntry `protobuf:"bytes,12,rep,name=CacheImports,proto3" json:"CacheImports,omitempty"`
	// apicaps:CapFrontendInputs
	FrontendInputs map[string]*pb.Definition `protobuf:"bytes,13,rep,name=FrontendInputs,proto3" json:"FrontendInputs,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	Evaluate       bool                      `protobuf:"varint,14,opt,name=Evaluate,proto3" json:"Evaluate,omitempty"`
	SourcePolicies []*pb1.Policy             `protobuf:"bytes,15,rep,name=SourcePolicies,proto3" json:"SourcePolicies,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *SolveRequest) Reset() {
	*x = SolveRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SolveRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SolveRequest) ProtoMessage() {}

func (x *SolveRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SolveRequest.ProtoReflect.Descriptor instead.
func (*SolveRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{16}
}

func (x *SolveRequest) GetDefinition() *pb.Definition {
	if x != nil {
		return x.Definition
	}
	return nil
}

func (x *SolveRequest) GetFrontend() string {
	if x != nil {
		return x.Frontend
	}
	return ""
}

func (x *SolveRequest) GetFrontendOpt() map[string]string {
	if x != nil {
		return x.FrontendOpt
	}
	return nil
}

func (x *SolveRequest) GetAllowResultReturn() bool {
	if x != nil {
		return x.AllowResultReturn
	}
	return false
}

func (x *SolveRequest) GetAllowResultArrayRef() bool {
	if x != nil {
		return x.AllowResultArrayRef
	}
	return false
}

func (x *SolveRequest) GetFinal() bool {
	if x != nil {
		return x.Final
	}
	return false
}

func (x *SolveRequest) GetExporterAttr() []byte {
	if x != nil {
		return x.ExporterAttr
	}
	return nil
}

func (x *SolveRequest) GetCacheImports() []*CacheOptionsEntry {
	if x != nil {
		return x.CacheImports
	}
	return nil
}

func (x *SolveRequest) GetFrontendInputs() map[string]*pb.Definition {
	if x != nil {
		return x.FrontendInputs
	}
	return nil
}

func (x *SolveRequest) GetEvaluate() bool {
	if x != nil {
		return x.Evaluate
	}
	return false
}

func (x *SolveRequest) GetSourcePolicies() []*pb1.Policy {
	if x != nil {
		return x.SourcePolicies
	}
	return nil
}

// CacheOptionsEntry corresponds to the control.CacheOptionsEntry
type CacheOptionsEntry struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Type          string                 `protobuf:"bytes,1,opt,name=Type,proto3" json:"Type,omitempty"`
	Attrs         map[string]string      `protobuf:"bytes,2,rep,name=Attrs,proto3" json:"Attrs,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CacheOptionsEntry) Reset() {
	*x = CacheOptionsEntry{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CacheOptionsEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CacheOptionsEntry) ProtoMessage() {}

func (x *CacheOptionsEntry) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CacheOptionsEntry.ProtoReflect.Descriptor instead.
func (*CacheOptionsEntry) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{17}
}

func (x *CacheOptionsEntry) GetType() string {
	if x != nil {
		return x.Type
	}
	return ""
}

func (x *CacheOptionsEntry) GetAttrs() map[string]string {
	if x != nil {
		return x.Attrs
	}
	return nil
}

type SolveResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// deprecated
	Ref string `protobuf:"bytes,1,opt,name=ref,proto3" json:"ref,omitempty"` // can be used by readfile request
	// these fields are returned when allowMapReturn was set
	Result        *Result `protobuf:"bytes,3,opt,name=result,proto3" json:"result,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SolveResponse) Reset() {
	*x = SolveResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SolveResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SolveResponse) ProtoMessage() {}

func (x *SolveResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SolveResponse.ProtoReflect.Descriptor instead.
func (*SolveResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{18}
}

func (x *SolveResponse) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

func (x *SolveResponse) GetResult() *Result {
	if x != nil {
		return x.Result
	}
	return nil
}

type ReadFileRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Ref           string                 `protobuf:"bytes,1,opt,name=Ref,proto3" json:"Ref,omitempty"`
	FilePath      string                 `protobuf:"bytes,2,opt,name=FilePath,proto3" json:"FilePath,omitempty"`
	Range         *FileRange             `protobuf:"bytes,3,opt,name=Range,proto3" json:"Range,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReadFileRequest) Reset() {
	*x = ReadFileRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReadFileRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReadFileRequest) ProtoMessage() {}

func (x *ReadFileRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReadFileRequest.ProtoReflect.Descriptor instead.
func (*ReadFileRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{19}
}

func (x *ReadFileRequest) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

func (x *ReadFileRequest) GetFilePath() string {
	if x != nil {
		return x.FilePath
	}
	return ""
}

func (x *ReadFileRequest) GetRange() *FileRange {
	if x != nil {
		return x.Range
	}
	return nil
}

type FileRange struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Offset        int64                  `protobuf:"varint,1,opt,name=Offset,proto3" json:"Offset,omitempty"`
	Length        int64                  `protobuf:"varint,2,opt,name=Length,proto3" json:"Length,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *FileRange) Reset() {
	*x = FileRange{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *FileRange) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*FileRange) ProtoMessage() {}

func (x *FileRange) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use FileRange.ProtoReflect.Descriptor instead.
func (*FileRange) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{20}
}

func (x *FileRange) GetOffset() int64 {
	if x != nil {
		return x.Offset
	}
	return 0
}

func (x *FileRange) GetLength() int64 {
	if x != nil {
		return x.Length
	}
	return 0
}

type ReadFileResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Data          []byte                 `protobuf:"bytes,1,opt,name=Data,proto3" json:"Data,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReadFileResponse) Reset() {
	*x = ReadFileResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReadFileResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReadFileResponse) ProtoMessage() {}

func (x *ReadFileResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReadFileResponse.ProtoReflect.Descriptor instead.
func (*ReadFileResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{21}
}

func (x *ReadFileResponse) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

type ReadDirRequest struct {
	state          protoimpl.MessageState `protogen:"open.v1"`
	Ref            string                 `protobuf:"bytes,1,opt,name=Ref,proto3" json:"Ref,omitempty"`
	DirPath        string                 `protobuf:"bytes,2,opt,name=DirPath,proto3" json:"DirPath,omitempty"`
	IncludePattern string                 `protobuf:"bytes,3,opt,name=IncludePattern,proto3" json:"IncludePattern,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *ReadDirRequest) Reset() {
	*x = ReadDirRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReadDirRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReadDirRequest) ProtoMessage() {}

func (x *ReadDirRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReadDirRequest.ProtoReflect.Descriptor instead.
func (*ReadDirRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{22}
}

func (x *ReadDirRequest) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

func (x *ReadDirRequest) GetDirPath() string {
	if x != nil {
		return x.DirPath
	}
	return ""
}

func (x *ReadDirRequest) GetIncludePattern() string {
	if x != nil {
		return x.IncludePattern
	}
	return ""
}

type ReadDirResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Entries       []*types.Stat          `protobuf:"bytes,1,rep,name=entries,proto3" json:"entries,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReadDirResponse) Reset() {
	*x = ReadDirResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReadDirResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReadDirResponse) ProtoMessage() {}

func (x *ReadDirResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReadDirResponse.ProtoReflect.Descriptor instead.
func (*ReadDirResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{23}
}

func (x *ReadDirResponse) GetEntries() []*types.Stat {
	if x != nil {
		return x.Entries
	}
	return nil
}

type StatFileRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Ref           string                 `protobuf:"bytes,1,opt,name=Ref,proto3" json:"Ref,omitempty"`
	Path          string                 `protobuf:"bytes,2,opt,name=Path,proto3" json:"Path,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *StatFileRequest) Reset() {
	*x = StatFileRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *StatFileRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*StatFileRequest) ProtoMessage() {}

func (x *StatFileRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use StatFileRequest.ProtoReflect.Descriptor instead.
func (*StatFileRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{24}
}

func (x *StatFileRequest) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

func (x *StatFileRequest) GetPath() string {
	if x != nil {
		return x.Path
	}
	return ""
}

type StatFileResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Stat          *types.Stat            `protobuf:"bytes,1,opt,name=stat,proto3" json:"stat,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *StatFileResponse) Reset() {
	*x = StatFileResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *StatFileResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*StatFileResponse) ProtoMessage() {}

func (x *StatFileResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use StatFileResponse.ProtoReflect.Descriptor instead.
func (*StatFileResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{25}
}

func (x *StatFileResponse) GetStat() *types.Stat {
	if x != nil {
		return x.Stat
	}
	return nil
}

type EvaluateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Ref           string                 `protobuf:"bytes,1,opt,name=Ref,proto3" json:"Ref,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateRequest) Reset() {
	*x = EvaluateRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateRequest) ProtoMessage() {}

func (x *EvaluateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateRequest.ProtoReflect.Descriptor instead.
func (*EvaluateRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{26}
}

func (x *EvaluateRequest) GetRef() string {
	if x != nil {
		return x.Ref
	}
	return ""
}

type EvaluateResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateResponse) Reset() {
	*x = EvaluateResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateResponse) ProtoMessage() {}

func (x *EvaluateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateResponse.ProtoReflect.Descriptor instead.
func (*EvaluateResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{27}
}

type PingRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PingRequest) Reset() {
	*x = PingRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PingRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PingRequest) ProtoMessage() {}

func (x *PingRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.
func (*PingRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{28}
}

type PongResponse struct {
	state           protoimpl.MessageState `protogen:"open.v1"`
	FrontendAPICaps []*pb2.APICap          `protobuf:"bytes,1,rep,name=FrontendAPICaps,proto3" json:"FrontendAPICaps,omitempty"`
	LLBCaps         []*pb2.APICap          `protobuf:"bytes,2,rep,name=LLBCaps,proto3" json:"LLBCaps,omitempty"`
	Workers         []*types1.WorkerRecord `protobuf:"bytes,3,rep,name=Workers,proto3" json:"Workers,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *PongResponse) Reset() {
	*x = PongResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PongResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PongResponse) ProtoMessage() {}

func (x *PongResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PongResponse.ProtoReflect.Descriptor instead.
func (*PongResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{29}
}

func (x *PongResponse) GetFrontendAPICaps() []*pb2.APICap {
	if x != nil {
		return x.FrontendAPICaps
	}
	return nil
}

func (x *PongResponse) GetLLBCaps() []*pb2.APICap {
	if x != nil {
		return x.LLBCaps
	}
	return nil
}

func (x *PongResponse) GetWorkers() []*types1.WorkerRecord {
	if x != nil {
		return x.Workers
	}
	return nil
}

type WarnRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Digest        string                 `protobuf:"bytes,1,opt,name=digest,proto3" json:"digest,omitempty"`
	Level         int64                  `protobuf:"varint,2,opt,name=level,proto3" json:"level,omitempty"`
	Short         []byte                 `protobuf:"bytes,3,opt,name=short,proto3" json:"short,omitempty"`
	Detail        [][]byte               `protobuf:"bytes,4,rep,name=detail,proto3" json:"detail,omitempty"`
	Url           string                 `protobuf:"bytes,5,opt,name=url,proto3" json:"url,omitempty"`
	Info          *pb.SourceInfo         `protobuf:"bytes,6,opt,name=info,proto3" json:"info,omitempty"`
	Ranges        []*pb.Range            `protobuf:"bytes,7,rep,name=ranges,proto3" json:"ranges,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *WarnRequest) Reset() {
	*x = WarnRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *WarnRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*WarnRequest) ProtoMessage() {}

func (x *WarnRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use WarnRequest.ProtoReflect.Descriptor instead.
func (*WarnRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{30}
}

func (x *WarnRequest) GetDigest() string {
	if x != nil {
		return x.Digest
	}
	return ""
}

func (x *WarnRequest) GetLevel() int64 {
	if x != nil {
		return x.Level
	}
	return 0
}

func (x *WarnRequest) GetShort() []byte {
	if x != nil {
		return x.Short
	}
	return nil
}

func (x *WarnRequest) GetDetail() [][]byte {
	if x != nil {
		return x.Detail
	}
	return nil
}

func (x *WarnRequest) GetUrl() string {
	if x != nil {
		return x.Url
	}
	return ""
}

func (x *WarnRequest) GetInfo() *pb.SourceInfo {
	if x != nil {
		return x.Info
	}
	return nil
}

func (x *WarnRequest) GetRanges() []*pb.Range {
	if x != nil {
		return x.Ranges
	}
	return nil
}

type WarnResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *WarnResponse) Reset() {
	*x = WarnResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *WarnResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*WarnResponse) ProtoMessage() {}

func (x *WarnResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use WarnResponse.ProtoReflect.Descriptor instead.
func (*WarnResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{31}
}

type NewContainerRequest struct {
	state       protoimpl.MessageState `protogen:"open.v1"`
	ContainerID string                 `protobuf:"bytes,1,opt,name=ContainerID,proto3" json:"ContainerID,omitempty"`
	// For mount input values we can use random identifiers passed with ref
	Mounts        []*pb.Mount           `protobuf:"bytes,2,rep,name=Mounts,proto3" json:"Mounts,omitempty"`
	Network       pb.NetMode            `protobuf:"varint,3,opt,name=Network,proto3,enum=pb.NetMode" json:"Network,omitempty"`
	Platform      *pb.Platform          `protobuf:"bytes,4,opt,name=platform,proto3" json:"platform,omitempty"`
	Constraints   *pb.WorkerConstraints `protobuf:"bytes,5,opt,name=constraints,proto3" json:"constraints,omitempty"`
	ExtraHosts    []*pb.HostIP          `protobuf:"bytes,6,rep,name=extraHosts,proto3" json:"extraHosts,omitempty"`
	Hostname      string                `protobuf:"bytes,7,opt,name=hostname,proto3" json:"hostname,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *NewContainerRequest) Reset() {
	*x = NewContainerRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *NewContainerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*NewContainerRequest) ProtoMessage() {}

func (x *NewContainerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use NewContainerRequest.ProtoReflect.Descriptor instead.
func (*NewContainerRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{32}
}

func (x *NewContainerRequest) GetContainerID() string {
	if x != nil {
		return x.ContainerID
	}
	return ""
}

func (x *NewContainerRequest) GetMounts() []*pb.Mount {
	if x != nil {
		return x.Mounts
	}
	return nil
}

func (x *NewContainerRequest) GetNetwork() pb.NetMode {
	if x != nil {
		return x.Network
	}
	return pb.NetMode(0)
}

func (x *NewContainerRequest) GetPlatform() *pb.Platform {
	if x != nil {
		return x.Platform
	}
	return nil
}

func (x *NewContainerRequest) GetConstraints() *pb.WorkerConstraints {
	if x != nil {
		return x.Constraints
	}
	return nil
}

func (x *NewContainerRequest) GetExtraHosts() []*pb.HostIP {
	if x != nil {
		return x.ExtraHosts
	}
	return nil
}

func (x *NewContainerRequest) GetHostname() string {
	if x != nil {
		return x.Hostname
	}
	return ""
}

type NewContainerResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *NewContainerResponse) Reset() {
	*x = NewContainerResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *NewContainerResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*NewContainerResponse) ProtoMessage() {}

func (x *NewContainerResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use NewContainerResponse.ProtoReflect.Descriptor instead.
func (*NewContainerResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{33}
}

type ReleaseContainerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	ContainerID   string                 `protobuf:"bytes,1,opt,name=ContainerID,proto3" json:"ContainerID,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReleaseContainerRequest) Reset() {
	*x = ReleaseContainerRequest{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReleaseContainerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReleaseContainerRequest) ProtoMessage() {}

func (x *ReleaseContainerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReleaseContainerRequest.ProtoReflect.Descriptor instead.
func (*ReleaseContainerRequest) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{34}
}

func (x *ReleaseContainerRequest) GetContainerID() string {
	if x != nil {
		return x.ContainerID
	}
	return ""
}

type ReleaseContainerResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ReleaseContainerResponse) Reset() {
	*x = ReleaseContainerResponse{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[35]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ReleaseContainerResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ReleaseContainerResponse) ProtoMessage() {}

func (x *ReleaseContainerResponse) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[35]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ReleaseContainerResponse.ProtoReflect.Descriptor instead.
func (*ReleaseContainerResponse) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{35}
}

type ExecMessage struct {
	state     protoimpl.MessageState `protogen:"open.v1"`
	ProcessID string                 `protobuf:"bytes,1,opt,name=ProcessID,proto3" json:"ProcessID,omitempty"`
	// Types that are valid to be assigned to Input:
	//
	//	*ExecMessage_Init
	//	*ExecMessage_File
	//	*ExecMessage_Resize
	//	*ExecMessage_Started
	//	*ExecMessage_Exit
	//	*ExecMessage_Done
	//	*ExecMessage_Signal
	Input         isExecMessage_Input `protobuf_oneof:"Input"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ExecMessage) Reset() {
	*x = ExecMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[36]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ExecMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ExecMessage) ProtoMessage() {}

func (x *ExecMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[36]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ExecMessage.ProtoReflect.Descriptor instead.
func (*ExecMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{36}
}

func (x *ExecMessage) GetProcessID() string {
	if x != nil {
		return x.ProcessID
	}
	return ""
}

func (x *ExecMessage) GetInput() isExecMessage_Input {
	if x != nil {
		return x.Input
	}
	return nil
}

func (x *ExecMessage) GetInit() *InitMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Init); ok {
			return x.Init
		}
	}
	return nil
}

func (x *ExecMessage) GetFile() *FdMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_File); ok {
			return x.File
		}
	}
	return nil
}

func (x *ExecMessage) GetResize() *ResizeMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Resize); ok {
			return x.Resize
		}
	}
	return nil
}

func (x *ExecMessage) GetStarted() *StartedMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Started); ok {
			return x.Started
		}
	}
	return nil
}

func (x *ExecMessage) GetExit() *ExitMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Exit); ok {
			return x.Exit
		}
	}
	return nil
}

func (x *ExecMessage) GetDone() *DoneMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Done); ok {
			return x.Done
		}
	}
	return nil
}

func (x *ExecMessage) GetSignal() *SignalMessage {
	if x != nil {
		if x, ok := x.Input.(*ExecMessage_Signal); ok {
			return x.Signal
		}
	}
	return nil
}

type isExecMessage_Input interface {
	isExecMessage_Input()
}

type ExecMessage_Init struct {
	// InitMessage sent from client to server will start a new process in a
	// container
	Init *InitMessage `protobuf:"bytes,2,opt,name=Init,proto3,oneof"`
}

type ExecMessage_File struct {
	// FdMessage used from client to server for input (stdin) and
	// from server to client for output (stdout, stderr)
	File *FdMessage `protobuf:"bytes,3,opt,name=File,proto3,oneof"`
}

type ExecMessage_Resize struct {
	// ResizeMessage used from client to server for terminal resize events
	Resize *ResizeMessage `protobuf:"bytes,4,opt,name=Resize,proto3,oneof"`
}

type ExecMessage_Started struct {
	// StartedMessage sent from server to client after InitMessage to
	// indicate the process has started.
	Started *StartedMessage `protobuf:"bytes,5,opt,name=Started,proto3,oneof"`
}

type ExecMessage_Exit struct {
	// ExitMessage sent from server to client will contain the exit code
	// when the process ends.
	Exit *ExitMessage `protobuf:"bytes,6,opt,name=Exit,proto3,oneof"`
}

type ExecMessage_Done struct {
	// DoneMessage from server to client will be the last message for any
	// process.  Note that FdMessage might be sent after ExitMessage.
	Done *DoneMessage `protobuf:"bytes,7,opt,name=Done,proto3,oneof"`
}

type ExecMessage_Signal struct {
	// SignalMessage is used from client to server to send signal events
	Signal *SignalMessage `protobuf:"bytes,8,opt,name=Signal,proto3,oneof"`
}

func (*ExecMessage_Init) isExecMessage_Input() {}

func (*ExecMessage_File) isExecMessage_Input() {}

func (*ExecMessage_Resize) isExecMessage_Input() {}

func (*ExecMessage_Started) isExecMessage_Input() {}

func (*ExecMessage_Exit) isExecMessage_Input() {}

func (*ExecMessage_Done) isExecMessage_Input() {}

func (*ExecMessage_Signal) isExecMessage_Input() {}

type InitMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	ContainerID   string                 `protobuf:"bytes,1,opt,name=ContainerID,proto3" json:"ContainerID,omitempty"`
	Meta          *pb.Meta               `protobuf:"bytes,2,opt,name=Meta,proto3" json:"Meta,omitempty"`
	Fds           []uint32               `protobuf:"varint,3,rep,packed,name=Fds,proto3" json:"Fds,omitempty"`
	Tty           bool                   `protobuf:"varint,4,opt,name=Tty,proto3" json:"Tty,omitempty"`
	Security      pb.SecurityMode        `protobuf:"varint,5,opt,name=Security,proto3,enum=pb.SecurityMode" json:"Security,omitempty"`
	Secretenv     []*pb.SecretEnv        `protobuf:"bytes,6,rep,name=secretenv,proto3" json:"secretenv,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *InitMessage) Reset() {
	*x = InitMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[37]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *InitMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*InitMessage) ProtoMessage() {}

func (x *InitMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[37]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use InitMessage.ProtoReflect.Descriptor instead.
func (*InitMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{37}
}

func (x *InitMessage) GetContainerID() string {
	if x != nil {
		return x.ContainerID
	}
	return ""
}

func (x *InitMessage) GetMeta() *pb.Meta {
	if x != nil {
		return x.Meta
	}
	return nil
}

func (x *InitMessage) GetFds() []uint32 {
	if x != nil {
		return x.Fds
	}
	return nil
}

func (x *InitMessage) GetTty() bool {
	if x != nil {
		return x.Tty
	}
	return false
}

func (x *InitMessage) GetSecurity() pb.SecurityMode {
	if x != nil {
		return x.Security
	}
	return pb.SecurityMode(0)
}

func (x *InitMessage) GetSecretenv() []*pb.SecretEnv {
	if x != nil {
		return x.Secretenv
	}
	return nil
}

type ExitMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Code          uint32                 `protobuf:"varint,1,opt,name=Code,proto3" json:"Code,omitempty"`
	Error         *status.Status         `protobuf:"bytes,2,opt,name=Error,proto3" json:"Error,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ExitMessage) Reset() {
	*x = ExitMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[38]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ExitMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ExitMessage) ProtoMessage() {}

func (x *ExitMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[38]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ExitMessage.ProtoReflect.Descriptor instead.
func (*ExitMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{38}
}

func (x *ExitMessage) GetCode() uint32 {
	if x != nil {
		return x.Code
	}
	return 0
}

func (x *ExitMessage) GetError() *status.Status {
	if x != nil {
		return x.Error
	}
	return nil
}

type StartedMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *StartedMessage) Reset() {
	*x = StartedMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[39]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *StartedMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*StartedMessage) ProtoMessage() {}

func (x *StartedMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[39]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use StartedMessage.ProtoReflect.Descriptor instead.
func (*StartedMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{39}
}

type DoneMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DoneMessage) Reset() {
	*x = DoneMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[40]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DoneMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DoneMessage) ProtoMessage() {}

func (x *DoneMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[40]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DoneMessage.ProtoReflect.Descriptor instead.
func (*DoneMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{40}
}

type FdMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Fd            uint32                 `protobuf:"varint,1,opt,name=Fd,proto3" json:"Fd,omitempty"`   // what fd the data was from
	EOF           bool                   `protobuf:"varint,2,opt,name=EOF,proto3" json:"EOF,omitempty"` // true if eof was reached
	Data          []byte                 `protobuf:"bytes,3,opt,name=Data,proto3" json:"Data,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *FdMessage) Reset() {
	*x = FdMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[41]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *FdMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*FdMessage) ProtoMessage() {}

func (x *FdMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[41]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use FdMessage.ProtoReflect.Descriptor instead.
func (*FdMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{41}
}

func (x *FdMessage) GetFd() uint32 {
	if x != nil {
		return x.Fd
	}
	return 0
}

func (x *FdMessage) GetEOF() bool {
	if x != nil {
		return x.EOF
	}
	return false
}

func (x *FdMessage) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

type ResizeMessage struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Rows          uint32                 `protobuf:"varint,1,opt,name=Rows,proto3" json:"Rows,omitempty"`
	Cols          uint32                 `protobuf:"varint,2,opt,name=Cols,proto3" json:"Cols,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResizeMessage) Reset() {
	*x = ResizeMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[42]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResizeMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResizeMessage) ProtoMessage() {}

func (x *ResizeMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[42]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResizeMessage.ProtoReflect.Descriptor instead.
func (*ResizeMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{42}
}

func (x *ResizeMessage) GetRows() uint32 {
	if x != nil {
		return x.Rows
	}
	return 0
}

func (x *ResizeMessage) GetCols() uint32 {
	if x != nil {
		return x.Cols
	}
	return 0
}

type SignalMessage struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// we only send name (ie HUP, INT) because the int values
	// are platform dependent.
	Name          string `protobuf:"bytes,1,opt,name=Name,proto3" json:"Name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SignalMessage) Reset() {
	*x = SignalMessage{}
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[43]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SignalMessage) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SignalMessage) ProtoMessage() {}

func (x *SignalMessage) ProtoReflect() protoreflect.Message {
	mi := &file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[43]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SignalMessage.ProtoReflect.Descriptor instead.
func (*SignalMessage) Descriptor() ([]byte, []int) {
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP(), []int{43}
}

func (x *SignalMessage) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

var File_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto protoreflect.FileDescriptor

const file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDesc = "" +
	"\n" +
	":github.com/moby/buildkit/frontend/gateway/pb/gateway.proto\x12\x19moby.buildkit.v1.frontend\x1a/github.com/moby/buildkit/api/types/worker.proto\x1a,github.com/moby/buildkit/solver/pb/ops.proto\x1a5github.com/moby/buildkit/sourcepolicy/pb/policy.proto\x1a3github.com/moby/buildkit/util/apicaps/pb/caps.proto\x1a-github.com/tonistiigi/fsutil/types/stat.proto\x1a\x17google/rpc/status.proto\"\xcb\x04\n" +
	"\x06Result\x12&\n" +
	"\rrefDeprecated\x18\x01 \x01(\tH\x00R\rrefDeprecated\x12U\n" +
	"\x0erefsDeprecated\x18\x02 \x01(\v2+.moby.buildkit.v1.frontend.RefMapDeprecatedH\x00R\x0erefsDeprecated\x122\n" +
	"\x03ref\x18\x03 \x01(\v2\x1e.moby.buildkit.v1.frontend.RefH\x00R\x03ref\x127\n" +
	"\x04refs\x18\x04 \x01(\v2!.moby.buildkit.v1.frontend.RefMapH\x00R\x04refs\x12K\n" +
	"\bmetadata\x18\n" +
	" \x03(\v2/.moby.buildkit.v1.frontend.Result.MetadataEntryR\bmetadata\x12W\n" +
	"\fattestations\x18\f \x03(\v23.moby.buildkit.v1.frontend.Result.AttestationsEntryR\fattestations\x1a;\n" +
	"\rMetadataEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\fR\x05value:\x028\x01\x1ah\n" +
	"\x11AttestationsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12=\n" +
	"\x05value\x18\x02 \x01(\v2'.moby.buildkit.v1.frontend.AttestationsR\x05value:\x028\x01B\b\n" +
	"\x06result\"\x96\x01\n" +
	"\x10RefMapDeprecated\x12I\n" +
	"\x04refs\x18\x01 \x03(\v25.moby.buildkit.v1.frontend.RefMapDeprecated.RefsEntryR\x04refs\x1a7\n" +
	"\tRefsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"7\n" +
	"\x03Ref\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12 \n" +
	"\x03def\x18\x02 \x01(\v2\x0e.pb.DefinitionR\x03def\"\xa2\x01\n" +
	"\x06RefMap\x12?\n" +
	"\x04refs\x18\x01 \x03(\v2+.moby.buildkit.v1.frontend.RefMap.RefsEntryR\x04refs\x1aW\n" +
	"\tRefsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x124\n" +
	"\x05value\x18\x02 \x01(\v2\x1e.moby.buildkit.v1.frontend.RefR\x05value:\x028\x01\"X\n" +
	"\fAttestations\x12H\n" +
	"\vattestation\x18\x01 \x03(\v2&.moby.buildkit.v1.frontend.AttestationR\vattestation\"\xa6\x03\n" +
	"\vAttestation\x12>\n" +
	"\x04kind\x18\x01 \x01(\x0e2*.moby.buildkit.v1.frontend.AttestationKindR\x04kind\x12P\n" +
	"\bmetadata\x18\x02 \x03(\v24.moby.buildkit.v1.frontend.Attestation.MetadataEntryR\bmetadata\x120\n" +
	"\x03ref\x18\x03 \x01(\v2\x1e.moby.buildkit.v1.frontend.RefR\x03ref\x12\x12\n" +
	"\x04path\x18\x04 \x01(\tR\x04path\x120\n" +
	"\x13inTotoPredicateType\x18\x05 \x01(\tR\x13inTotoPredicateType\x12P\n" +
	"\x0einTotoSubjects\x18\x06 \x03(\v2(.moby.buildkit.v1.frontend.InTotoSubjectR\x0einTotoSubjects\x1a;\n" +
	"\rMetadataEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\fR\x05value:\x028\x01\"}\n" +
	"\rInTotoSubject\x12@\n" +
	"\x04kind\x18\x01 \x01(\x0e2,.moby.buildkit.v1.frontend.InTotoSubjectKindR\x04kind\x12\x16\n" +
	"\x06digest\x18\x02 \x03(\tR\x06digest\x12\x12\n" +
	"\x04name\x18\x03 \x01(\tR\x04name\"t\n" +
	"\rReturnRequest\x129\n" +
	"\x06result\x18\x01 \x01(\v2!.moby.buildkit.v1.frontend.ResultR\x06result\x12(\n" +
	"\x05error\x18\x02 \x01(\v2\x12.google.rpc.StatusR\x05error\"\x10\n" +
	"\x0eReturnResponse\"\x0f\n" +
	"\rInputsRequest\"\xbe\x01\n" +
	"\x0eInputsResponse\x12\\\n" +
	"\vDefinitions\x18\x01 \x03(\v2:.moby.buildkit.v1.frontend.InputsResponse.DefinitionsEntryR\vDefinitions\x1aN\n" +
	"\x10DefinitionsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12$\n" +
	"\x05value\x18\x02 \x01(\v2\x0e.pb.DefinitionR\x05value:\x028\x01\"\xbe\x02\n" +
	"\x19ResolveImageConfigRequest\x12\x10\n" +
	"\x03Ref\x18\x01 \x01(\tR\x03Ref\x12(\n" +
	"\bPlatform\x18\x02 \x01(\v2\f.pb.PlatformR\bPlatform\x12 \n" +
	"\vResolveMode\x18\x03 \x01(\tR\vResolveMode\x12\x18\n" +
	"\aLogName\x18\x04 \x01(\tR\aLogName\x12\"\n" +
	"\fResolverType\x18\x05 \x01(\x05R\fResolverType\x12\x1c\n" +
	"\tSessionID\x18\x06 \x01(\tR\tSessionID\x12\x18\n" +
	"\aStoreID\x18\a \x01(\tR\aStoreID\x12M\n" +
	"\x0eSourcePolicies\x18\b \x03(\v2%.moby.buildkit.v1.sourcepolicy.PolicyR\x0eSourcePolicies\"^\n" +
	"\x1aResolveImageConfigResponse\x12\x16\n" +
	"\x06Digest\x18\x01 \x01(\tR\x06Digest\x12\x16\n" +
	"\x06Config\x18\x02 \x01(\fR\x06Config\x12\x10\n" +
	"\x03Ref\x18\x03 \x01(\tR\x03Ref\"\xf5\x01\n" +
	"\x18ResolveSourceMetaRequest\x12$\n" +
	"\x06Source\x18\x01 \x01(\v2\f.pb.SourceOpR\x06Source\x12(\n" +
	"\bPlatform\x18\x02 \x01(\v2\f.pb.PlatformR\bPlatform\x12\x18\n" +
	"\aLogName\x18\x03 \x01(\tR\aLogName\x12 \n" +
	"\vResolveMode\x18\x04 \x01(\tR\vResolveMode\x12M\n" +
	"\x0eSourcePolicies\x18\b \x03(\v2%.moby.buildkit.v1.sourcepolicy.PolicyR\x0eSourcePolicies\"\x8e\x01\n" +
	"\x19ResolveSourceMetaResponse\x12$\n" +
	"\x06Source\x18\x01 \x01(\v2\f.pb.SourceOpR\x06Source\x12K\n" +
	"\x05Image\x18\x02 \x01(\v25.moby.buildkit.v1.frontend.ResolveSourceImageResponseR\x05Image\"L\n" +
	"\x1aResolveSourceImageResponse\x12\x16\n" +
	"\x06Digest\x18\x01 \x01(\tR\x06Digest\x12\x16\n" +
	"\x06Config\x18\x02 \x01(\fR\x06Config\"\x85\x06\n" +
	"\fSolveRequest\x12.\n" +
	"\n" +
	"Definition\x18\x01 \x01(\v2\x0e.pb.DefinitionR\n" +
	"Definition\x12\x1a\n" +
	"\bFrontend\x18\x02 \x01(\tR\bFrontend\x12Z\n" +
	"\vFrontendOpt\x18\x03 \x03(\v28.moby.buildkit.v1.frontend.SolveRequest.FrontendOptEntryR\vFrontendOpt\x12,\n" +
	"\x11allowResultReturn\x18\x05 \x01(\bR\x11allowResultReturn\x120\n" +
	"\x13allowResultArrayRef\x18\x06 \x01(\bR\x13allowResultArrayRef\x12\x14\n" +
	"\x05Final\x18\n" +
	" \x01(\bR\x05Final\x12\"\n" +
	"\fExporterAttr\x18\v \x01(\fR\fExporterAttr\x12P\n" +
	"\fCacheImports\x18\f \x03(\v2,.moby.buildkit.v1.frontend.CacheOptionsEntryR\fCacheImports\x12c\n" +
	"\x0eFrontendInputs\x18\r \x03(\v2;.moby.buildkit.v1.frontend.SolveRequest.FrontendInputsEntryR\x0eFrontendInputs\x12\x1a\n" +
	"\bEvaluate\x18\x0e \x01(\bR\bEvaluate\x12M\n" +
	"\x0eSourcePolicies\x18\x0f \x03(\v2%.moby.buildkit.v1.sourcepolicy.PolicyR\x0eSourcePolicies\x1a>\n" +
	"\x10FrontendOptEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\x1aQ\n" +
	"\x13FrontendInputsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12$\n" +
	"\x05value\x18\x02 \x01(\v2\x0e.pb.DefinitionR\x05value:\x028\x01\"\xb0\x01\n" +
	"\x11CacheOptionsEntry\x12\x12\n" +
	"\x04Type\x18\x01 \x01(\tR\x04Type\x12M\n" +
	"\x05Attrs\x18\x02 \x03(\v27.moby.buildkit.v1.frontend.CacheOptionsEntry.AttrsEntryR\x05Attrs\x1a8\n" +
	"\n" +
	"AttrsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"\\\n" +
	"\rSolveResponse\x12\x10\n" +
	"\x03ref\x18\x01 \x01(\tR\x03ref\x129\n" +
	"\x06result\x18\x03 \x01(\v2!.moby.buildkit.v1.frontend.ResultR\x06result\"{\n" +
	"\x0fReadFileRequest\x12\x10\n" +
	"\x03Ref\x18\x01 \x01(\tR\x03Ref\x12\x1a\n" +
	"\bFilePath\x18\x02 \x01(\tR\bFilePath\x12:\n" +
	"\x05Range\x18\x03 \x01(\v2$.moby.buildkit.v1.frontend.FileRangeR\x05Range\";\n" +
	"\tFileRange\x12\x16\n" +
	"\x06Offset\x18\x01 \x01(\x03R\x06Offset\x12\x16\n" +
	"\x06Length\x18\x02 \x01(\x03R\x06Length\"&\n" +
	"\x10ReadFileResponse\x12\x12\n" +
	"\x04Data\x18\x01 \x01(\fR\x04Data\"d\n" +
	"\x0eReadDirRequest\x12\x10\n" +
	"\x03Ref\x18\x01 \x01(\tR\x03Ref\x12\x18\n" +
	"\aDirPath\x18\x02 \x01(\tR\aDirPath\x12&\n" +
	"\x0eIncludePattern\x18\x03 \x01(\tR\x0eIncludePattern\"?\n" +
	"\x0fReadDirResponse\x12,\n" +
	"\aentries\x18\x01 \x03(\v2\x12.fsutil.types.StatR\aentries\"7\n" +
	"\x0fStatFileRequest\x12\x10\n" +
	"\x03Ref\x18\x01 \x01(\tR\x03Ref\x12\x12\n" +
	"\x04Path\x18\x02 \x01(\tR\x04Path\":\n" +
	"\x10StatFileResponse\x12&\n" +
	"\x04stat\x18\x01 \x01(\v2\x12.fsutil.types.StatR\x04stat\"#\n" +
	"\x0fEvaluateRequest\x12\x10\n" +
	"\x03Ref\x18\x01 \x01(\tR\x03Ref\"\x12\n" +
	"\x10EvaluateResponse\"\r\n" +
	"\vPingRequest\"\xd6\x01\n" +
	"\fPongResponse\x12J\n" +
	"\x0fFrontendAPICaps\x18\x01 \x03(\v2 .moby.buildkit.v1.apicaps.APICapR\x0fFrontendAPICaps\x12:\n" +
	"\aLLBCaps\x18\x02 \x03(\v2 .moby.buildkit.v1.apicaps.APICapR\aLLBCaps\x12>\n" +
	"\aWorkers\x18\x03 \x03(\v2$.moby.buildkit.v1.types.WorkerRecordR\aWorkers\"\xc2\x01\n" +
	"\vWarnRequest\x12\x16\n" +
	"\x06digest\x18\x01 \x01(\tR\x06digest\x12\x14\n" +
	"\x05level\x18\x02 \x01(\x03R\x05level\x12\x14\n" +
	"\x05short\x18\x03 \x01(\fR\x05short\x12\x16\n" +
	"\x06detail\x18\x04 \x03(\fR\x06detail\x12\x10\n" +
	"\x03url\x18\x05 \x01(\tR\x03url\x12\"\n" +
	"\x04info\x18\x06 \x01(\v2\x0e.pb.SourceInfoR\x04info\x12!\n" +
	"\x06ranges\x18\a \x03(\v2\t.pb.RangeR\x06ranges\"\x0e\n" +
	"\fWarnResponse\"\xac\x02\n" +
	"\x13NewContainerRequest\x12 \n" +
	"\vContainerID\x18\x01 \x01(\tR\vContainerID\x12!\n" +
	"\x06Mounts\x18\x02 \x03(\v2\t.pb.MountR\x06Mounts\x12%\n" +
	"\aNetwork\x18\x03 \x01(\x0e2\v.pb.NetModeR\aNetwork\x12(\n" +
	"\bplatform\x18\x04 \x01(\v2\f.pb.PlatformR\bplatform\x127\n" +
	"\vconstraints\x18\x05 \x01(\v2\x15.pb.WorkerConstraintsR\vconstraints\x12*\n" +
	"\n" +
	"extraHosts\x18\x06 \x03(\v2\n" +
	".pb.HostIPR\n" +
	"extraHosts\x12\x1a\n" +
	"\bhostname\x18\a \x01(\tR\bhostname\"\x16\n" +
	"\x14NewContainerResponse\";\n" +
	"\x17ReleaseContainerRequest\x12 \n" +
	"\vContainerID\x18\x01 \x01(\tR\vContainerID\"\x1a\n" +
	"\x18ReleaseContainerResponse\"\xf9\x03\n" +
	"\vExecMessage\x12\x1c\n" +
	"\tProcessID\x18\x01 \x01(\tR\tProcessID\x12<\n" +
	"\x04Init\x18\x02 \x01(\v2&.moby.buildkit.v1.frontend.InitMessageH\x00R\x04Init\x12:\n" +
	"\x04File\x18\x03 \x01(\v2$.moby.buildkit.v1.frontend.FdMessageH\x00R\x04File\x12B\n" +
	"\x06Resize\x18\x04 \x01(\v2(.moby.buildkit.v1.frontend.ResizeMessageH\x00R\x06Resize\x12E\n" +
	"\aStarted\x18\x05 \x01(\v2).moby.buildkit.v1.frontend.StartedMessageH\x00R\aStarted\x12<\n" +
	"\x04Exit\x18\x06 \x01(\v2&.moby.buildkit.v1.frontend.ExitMessageH\x00R\x04Exit\x12<\n" +
	"\x04Done\x18\a \x01(\v2&.moby.buildkit.v1.frontend.DoneMessageH\x00R\x04Done\x12B\n" +
	"\x06Signal\x18\b \x01(\v2(.moby.buildkit.v1.frontend.SignalMessageH\x00R\x06SignalB\a\n" +
	"\x05Input\"\xcc\x01\n" +
	"\vInitMessage\x12 \n" +
	"\vContainerID\x18\x01 \x01(\tR\vContainerID\x12\x1c\n" +
	"\x04Meta\x18\x02 \x01(\v2\b.pb.MetaR\x04Meta\x12\x10\n" +
	"\x03Fds\x18\x03 \x03(\rR\x03Fds\x12\x10\n" +
	"\x03Tty\x18\x04 \x01(\bR\x03Tty\x12,\n" +
	"\bSecurity\x18\x05 \x01(\x0e2\x10.pb.SecurityModeR\bSecurity\x12+\n" +
	"\tsecretenv\x18\x06 \x03(\v2\r.pb.SecretEnvR\tsecretenv\"K\n" +
	"\vExitMessage\x12\x12\n" +
	"\x04Code\x18\x01 \x01(\rR\x04Code\x12(\n" +
	"\x05Error\x18\x02 \x01(\v2\x12.google.rpc.StatusR\x05Error\"\x10\n" +
	"\x0eStartedMessage\"\r\n" +
	"\vDoneMessage\"A\n" +
	"\tFdMessage\x12\x0e\n" +
	"\x02Fd\x18\x01 \x01(\rR\x02Fd\x12\x10\n" +
	"\x03EOF\x18\x02 \x01(\bR\x03EOF\x12\x12\n" +
	"\x04Data\x18\x03 \x01(\fR\x04Data\"7\n" +
	"\rResizeMessage\x12\x12\n" +
	"\x04Rows\x18\x01 \x01(\rR\x04Rows\x12\x12\n" +
	"\x04Cols\x18\x02 \x01(\rR\x04Cols\"#\n" +
	"\rSignalMessage\x12\x12\n" +
	"\x04Name\x18\x01 \x01(\tR\x04Name*)\n" +
	"\x0fAttestationKind\x12\n" +
	"\n" +
	"\x06InToto\x10\x00\x12\n" +
	"\n" +
	"\x06Bundle\x10\x01*&\n" +
	"\x11InTotoSubjectKind\x12\b\n" +
	"\x04Self\x10\x00\x12\a\n" +
	"\x03Raw\x10\x012\xbd\v\n" +
	"\tLLBBridge\x12\x81\x01\n" +
	"\x12ResolveImageConfig\x124.moby.buildkit.v1.frontend.ResolveImageConfigRequest\x1a5.moby.buildkit.v1.frontend.ResolveImageConfigResponse\x12~\n" +
	"\x11ResolveSourceMeta\x123.moby.buildkit.v1.frontend.ResolveSourceMetaRequest\x1a4.moby.buildkit.v1.frontend.ResolveSourceMetaResponse\x12Z\n" +
	"\x05Solve\x12'.moby.buildkit.v1.frontend.SolveRequest\x1a(.moby.buildkit.v1.frontend.SolveResponse\x12c\n" +
	"\bReadFile\x12*.moby.buildkit.v1.frontend.ReadFileRequest\x1a+.moby.buildkit.v1.frontend.ReadFileResponse\x12`\n" +
	"\aReadDir\x12).moby.buildkit.v1.frontend.ReadDirRequest\x1a*.moby.buildkit.v1.frontend.ReadDirResponse\x12c\n" +
	"\bStatFile\x12*.moby.buildkit.v1.frontend.StatFileRequest\x1a+.moby.buildkit.v1.frontend.StatFileResponse\x12c\n" +
	"\bEvaluate\x12*.moby.buildkit.v1.frontend.EvaluateRequest\x1a+.moby.buildkit.v1.frontend.EvaluateResponse\x12W\n" +
	"\x04Ping\x12&.moby.buildkit.v1.frontend.PingRequest\x1a'.moby.buildkit.v1.frontend.PongResponse\x12]\n" +
	"\x06Return\x12(.moby.buildkit.v1.frontend.ReturnRequest\x1a).moby.buildkit.v1.frontend.ReturnResponse\x12]\n" +
	"\x06Inputs\x12(.moby.buildkit.v1.frontend.InputsRequest\x1a).moby.buildkit.v1.frontend.InputsResponse\x12o\n" +
	"\fNewContainer\x12..moby.buildkit.v1.frontend.NewContainerRequest\x1a/.moby.buildkit.v1.frontend.NewContainerResponse\x12{\n" +
	"\x10ReleaseContainer\x122.moby.buildkit.v1.frontend.ReleaseContainerRequest\x1a3.moby.buildkit.v1.frontend.ReleaseContainerResponse\x12a\n" +
	"\vExecProcess\x12&.moby.buildkit.v1.frontend.ExecMessage\x1a&.moby.buildkit.v1.frontend.ExecMessage(\x010\x01\x12W\n" +
	"\x04Warn\x12&.moby.buildkit.v1.frontend.WarnRequest\x1a'.moby.buildkit.v1.frontend.WarnResponseBHZFgithub.com/moby/buildkit/frontend/gateway/pb;moby_buildkit_v1_frontendb\x06proto3"

var (
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescOnce sync.Once
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescData []byte
)

func file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescGZIP() []byte {
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescOnce.Do(func() {
		file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDesc), len(file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDesc)))
	})
	return file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDescData
}

var file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes = make([]protoimpl.EnumInfo, 2)
var file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes = make([]protoimpl.MessageInfo, 53)
var file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_goTypes = []any{
	(AttestationKind)(0),               // 0: moby.buildkit.v1.frontend.AttestationKind
	(InTotoSubjectKind)(0),             // 1: moby.buildkit.v1.frontend.InTotoSubjectKind
	(*Result)(nil),                     // 2: moby.buildkit.v1.frontend.Result
	(*RefMapDeprecated)(nil),           // 3: moby.buildkit.v1.frontend.RefMapDeprecated
	(*Ref)(nil),                        // 4: moby.buildkit.v1.frontend.Ref
	(*RefMap)(nil),                     // 5: moby.buildkit.v1.frontend.RefMap
	(*Attestations)(nil),               // 6: moby.buildkit.v1.frontend.Attestations
	(*Attestation)(nil),                // 7: moby.buildkit.v1.frontend.Attestation
	(*InTotoSubject)(nil),              // 8: moby.buildkit.v1.frontend.InTotoSubject
	(*ReturnRequest)(nil),              // 9: moby.buildkit.v1.frontend.ReturnRequest
	(*ReturnResponse)(nil),             // 10: moby.buildkit.v1.frontend.ReturnResponse
	(*InputsRequest)(nil),              // 11: moby.buildkit.v1.frontend.InputsRequest
	(*InputsResponse)(nil),             // 12: moby.buildkit.v1.frontend.InputsResponse
	(*ResolveImageConfigRequest)(nil),  // 13: moby.buildkit.v1.frontend.ResolveImageConfigRequest
	(*ResolveImageConfigResponse)(nil), // 14: moby.buildkit.v1.frontend.ResolveImageConfigResponse
	(*ResolveSourceMetaRequest)(nil),   // 15: moby.buildkit.v1.frontend.ResolveSourceMetaRequest
	(*ResolveSourceMetaResponse)(nil),  // 16: moby.buildkit.v1.frontend.ResolveSourceMetaResponse
	(*ResolveSourceImageResponse)(nil), // 17: moby.buildkit.v1.frontend.ResolveSourceImageResponse
	(*SolveRequest)(nil),               // 18: moby.buildkit.v1.frontend.SolveRequest
	(*CacheOptionsEntry)(nil),          // 19: moby.buildkit.v1.frontend.CacheOptionsEntry
	(*SolveResponse)(nil),              // 20: moby.buildkit.v1.frontend.SolveResponse
	(*ReadFileRequest)(nil),            // 21: moby.buildkit.v1.frontend.ReadFileRequest
	(*FileRange)(nil),                  // 22: moby.buildkit.v1.frontend.FileRange
	(*ReadFileResponse)(nil),           // 23: moby.buildkit.v1.frontend.ReadFileResponse
	(*ReadDirRequest)(nil),             // 24: moby.buildkit.v1.frontend.ReadDirRequest
	(*ReadDirResponse)(nil),            // 25: moby.buildkit.v1.frontend.ReadDirResponse
	(*StatFileRequest)(nil),            // 26: moby.buildkit.v1.frontend.StatFileRequest
	(*StatFileResponse)(nil),           // 27: moby.buildkit.v1.frontend.StatFileResponse
	(*EvaluateRequest)(nil),            // 28: moby.buildkit.v1.frontend.EvaluateRequest
	(*EvaluateResponse)(nil),           // 29: moby.buildkit.v1.frontend.EvaluateResponse
	(*PingRequest)(nil),                // 30: moby.buildkit.v1.frontend.PingRequest
	(*PongResponse)(nil),               // 31: moby.buildkit.v1.frontend.PongResponse
	(*WarnRequest)(nil),                // 32: moby.buildkit.v1.frontend.WarnRequest
	(*WarnResponse)(nil),               // 33: moby.buildkit.v1.frontend.WarnResponse
	(*NewContainerRequest)(nil),        // 34: moby.buildkit.v1.frontend.NewContainerRequest
	(*NewContainerResponse)(nil),       // 35: moby.buildkit.v1.frontend.NewContainerResponse
	(*ReleaseContainerRequest)(nil),    // 36: moby.buildkit.v1.frontend.ReleaseContainerRequest
	(*ReleaseContainerResponse)(nil),   // 37: moby.buildkit.v1.frontend.ReleaseContainerResponse
	(*ExecMessage)(nil),                // 38: moby.buildkit.v1.frontend.ExecMessage
	(*InitMessage)(nil),                // 39: moby.buildkit.v1.frontend.InitMessage
	(*ExitMessage)(nil),                // 40: moby.buildkit.v1.frontend.ExitMessage
	(*StartedMessage)(nil),             // 41: moby.buildkit.v1.frontend.StartedMessage
	(*DoneMessage)(nil),                // 42: moby.buildkit.v1.frontend.DoneMessage
	(*FdMessage)(nil),                  // 43: moby.buildkit.v1.frontend.FdMessage
	(*ResizeMessage)(nil),              // 44: moby.buildkit.v1.frontend.ResizeMessage
	(*SignalMessage)(nil),              // 45: moby.buildkit.v1.frontend.SignalMessage
	nil,                                // 46: moby.buildkit.v1.frontend.Result.MetadataEntry
	nil,                                // 47: moby.buildkit.v1.frontend.Result.AttestationsEntry
	nil,                                // 48: moby.buildkit.v1.frontend.RefMapDeprecated.RefsEntry
	nil,                                // 49: moby.buildkit.v1.frontend.RefMap.RefsEntry
	nil,                                // 50: moby.buildkit.v1.frontend.Attestation.MetadataEntry
	nil,                                // 51: moby.buildkit.v1.frontend.InputsResponse.DefinitionsEntry
	nil,                                // 52: moby.buildkit.v1.frontend.SolveRequest.FrontendOptEntry
	nil,                                // 53: moby.buildkit.v1.frontend.SolveRequest.FrontendInputsEntry
	nil,                                // 54: moby.buildkit.v1.frontend.CacheOptionsEntry.AttrsEntry
	(*pb.Definition)(nil),              // 55: pb.Definition
	(*status.Status)(nil),              // 56: google.rpc.Status
	(*pb.Platform)(nil),                // 57: pb.Platform
	(*pb1.Policy)(nil),                 // 58: moby.buildkit.v1.sourcepolicy.Policy
	(*pb.SourceOp)(nil),                // 59: pb.SourceOp
	(*types.Stat)(nil),                 // 60: fsutil.types.Stat
	(*pb2.APICap)(nil),                 // 61: moby.buildkit.v1.apicaps.APICap
	(*types1.WorkerRecord)(nil),        // 62: moby.buildkit.v1.types.WorkerRecord
	(*pb.SourceInfo)(nil),              // 63: pb.SourceInfo
	(*pb.Range)(nil),                   // 64: pb.Range
	(*pb.Mount)(nil),                   // 65: pb.Mount
	(pb.NetMode)(0),                    // 66: pb.NetMode
	(*pb.WorkerConstraints)(nil),       // 67: pb.WorkerConstraints
	(*pb.HostIP)(nil),                  // 68: pb.HostIP
	(*pb.Meta)(nil),                    // 69: pb.Meta
	(pb.SecurityMode)(0),               // 70: pb.SecurityMode
	(*pb.SecretEnv)(nil),               // 71: pb.SecretEnv
}
var file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_depIdxs = []int32{
	3,  // 0: moby.buildkit.v1.frontend.Result.refsDeprecated:type_name -> moby.buildkit.v1.frontend.RefMapDeprecated
	4,  // 1: moby.buildkit.v1.frontend.Result.ref:type_name -> moby.buildkit.v1.frontend.Ref
	5,  // 2: moby.buildkit.v1.frontend.Result.refs:type_name -> moby.buildkit.v1.frontend.RefMap
	46, // 3: moby.buildkit.v1.frontend.Result.metadata:type_name -> moby.buildkit.v1.frontend.Result.MetadataEntry
	47, // 4: moby.buildkit.v1.frontend.Result.attestations:type_name -> moby.buildkit.v1.frontend.Result.AttestationsEntry
	48, // 5: moby.buildkit.v1.frontend.RefMapDeprecated.refs:type_name -> moby.buildkit.v1.frontend.RefMapDeprecated.RefsEntry
	55, // 6: moby.buildkit.v1.frontend.Ref.def:type_name -> pb.Definition
	49, // 7: moby.buildkit.v1.frontend.RefMap.refs:type_name -> moby.buildkit.v1.frontend.RefMap.RefsEntry
	7,  // 8: moby.buildkit.v1.frontend.Attestations.attestation:type_name -> moby.buildkit.v1.frontend.Attestation
	0,  // 9: moby.buildkit.v1.frontend.Attestation.kind:type_name -> moby.buildkit.v1.frontend.AttestationKind
	50, // 10: moby.buildkit.v1.frontend.Attestation.metadata:type_name -> moby.buildkit.v1.frontend.Attestation.MetadataEntry
	4,  // 11: moby.buildkit.v1.frontend.Attestation.ref:type_name -> moby.buildkit.v1.frontend.Ref
	8,  // 12: moby.buildkit.v1.frontend.Attestation.inTotoSubjects:type_name -> moby.buildkit.v1.frontend.InTotoSubject
	1,  // 13: moby.buildkit.v1.frontend.InTotoSubject.kind:type_name -> moby.buildkit.v1.frontend.InTotoSubjectKind
	2,  // 14: moby.buildkit.v1.frontend.ReturnRequest.result:type_name -> moby.buildkit.v1.frontend.Result
	56, // 15: moby.buildkit.v1.frontend.ReturnRequest.error:type_name -> google.rpc.Status
	51, // 16: moby.buildkit.v1.frontend.InputsResponse.Definitions:type_name -> moby.buildkit.v1.frontend.InputsResponse.DefinitionsEntry
	57, // 17: moby.buildkit.v1.frontend.ResolveImageConfigRequest.Platform:type_name -> pb.Platform
	58, // 18: moby.buildkit.v1.frontend.ResolveImageConfigRequest.SourcePolicies:type_name -> moby.buildkit.v1.sourcepolicy.Policy
	59, // 19: moby.buildkit.v1.frontend.ResolveSourceMetaRequest.Source:type_name -> pb.SourceOp
	57, // 20: moby.buildkit.v1.frontend.ResolveSourceMetaRequest.Platform:type_name -> pb.Platform
	58, // 21: moby.buildkit.v1.frontend.ResolveSourceMetaRequest.SourcePolicies:type_name -> moby.buildkit.v1.sourcepolicy.Policy
	59, // 22: moby.buildkit.v1.frontend.ResolveSourceMetaResponse.Source:type_name -> pb.SourceOp
	17, // 23: moby.buildkit.v1.frontend.ResolveSourceMetaResponse.Image:type_name -> moby.buildkit.v1.frontend.ResolveSourceImageResponse
	55, // 24: moby.buildkit.v1.frontend.SolveRequest.Definition:type_name -> pb.Definition
	52, // 25: moby.buildkit.v1.frontend.SolveRequest.FrontendOpt:type_name -> moby.buildkit.v1.frontend.SolveRequest.FrontendOptEntry
	19, // 26: moby.buildkit.v1.frontend.SolveRequest.CacheImports:type_name -> moby.buildkit.v1.frontend.CacheOptionsEntry
	53, // 27: moby.buildkit.v1.frontend.SolveRequest.FrontendInputs:type_name -> moby.buildkit.v1.frontend.SolveRequest.FrontendInputsEntry
	58, // 28: moby.buildkit.v1.frontend.SolveRequest.SourcePolicies:type_name -> moby.buildkit.v1.sourcepolicy.Policy
	54, // 29: moby.buildkit.v1.frontend.CacheOptionsEntry.Attrs:type_name -> moby.buildkit.v1.frontend.CacheOptionsEntry.AttrsEntry
	2,  // 30: moby.buildkit.v1.frontend.SolveResponse.result:type_name -> moby.buildkit.v1.frontend.Result
	22, // 31: moby.buildkit.v1.frontend.ReadFileRequest.Range:type_name -> moby.buildkit.v1.frontend.FileRange
	60, // 32: moby.buildkit.v1.frontend.ReadDirResponse.entries:type_name -> fsutil.types.Stat
	60, // 33: moby.buildkit.v1.frontend.StatFileResponse.stat:type_name -> fsutil.types.Stat
	61, // 34: moby.buildkit.v1.frontend.PongResponse.FrontendAPICaps:type_name -> moby.buildkit.v1.apicaps.APICap
	61, // 35: moby.buildkit.v1.frontend.PongResponse.LLBCaps:type_name -> moby.buildkit.v1.apicaps.APICap
	62, // 36: moby.buildkit.v1.frontend.PongResponse.Workers:type_name -> moby.buildkit.v1.types.WorkerRecord
	63, // 37: moby.buildkit.v1.frontend.WarnRequest.info:type_name -> pb.SourceInfo
	64, // 38: moby.buildkit.v1.frontend.WarnRequest.ranges:type_name -> pb.Range
	65, // 39: moby.buildkit.v1.frontend.NewContainerRequest.Mounts:type_name -> pb.Mount
	66, // 40: moby.buildkit.v1.frontend.NewContainerRequest.Network:type_name -> pb.NetMode
	57, // 41: moby.buildkit.v1.frontend.NewContainerRequest.platform:type_name -> pb.Platform
	67, // 42: moby.buildkit.v1.frontend.NewContainerRequest.constraints:type_name -> pb.WorkerConstraints
	68, // 43: moby.buildkit.v1.frontend.NewContainerRequest.extraHosts:type_name -> pb.HostIP
	39, // 44: moby.buildkit.v1.frontend.ExecMessage.Init:type_name -> moby.buildkit.v1.frontend.InitMessage
	43, // 45: moby.buildkit.v1.frontend.ExecMessage.File:type_name -> moby.buildkit.v1.frontend.FdMessage
	44, // 46: moby.buildkit.v1.frontend.ExecMessage.Resize:type_name -> moby.buildkit.v1.frontend.ResizeMessage
	41, // 47: moby.buildkit.v1.frontend.ExecMessage.Started:type_name -> moby.buildkit.v1.frontend.StartedMessage
	40, // 48: moby.buildkit.v1.frontend.ExecMessage.Exit:type_name -> moby.buildkit.v1.frontend.ExitMessage
	42, // 49: moby.buildkit.v1.frontend.ExecMessage.Done:type_name -> moby.buildkit.v1.frontend.DoneMessage
	45, // 50: moby.buildkit.v1.frontend.ExecMessage.Signal:type_name -> moby.buildkit.v1.frontend.SignalMessage
	69, // 51: moby.buildkit.v1.frontend.InitMessage.Meta:type_name -> pb.Meta
	70, // 52: moby.buildkit.v1.frontend.InitMessage.Security:type_name -> pb.SecurityMode
	71, // 53: moby.buildkit.v1.frontend.InitMessage.secretenv:type_name -> pb.SecretEnv
	56, // 54: moby.buildkit.v1.frontend.ExitMessage.Error:type_name -> google.rpc.Status
	6,  // 55: moby.buildkit.v1.frontend.Result.AttestationsEntry.value:type_name -> moby.buildkit.v1.frontend.Attestations
	4,  // 56: moby.buildkit.v1.frontend.RefMap.RefsEntry.value:type_name -> moby.buildkit.v1.frontend.Ref
	55, // 57: moby.buildkit.v1.frontend.InputsResponse.DefinitionsEntry.value:type_name -> pb.Definition
	55, // 58: moby.buildkit.v1.frontend.SolveRequest.FrontendInputsEntry.value:type_name -> pb.Definition
	13, // 59: moby.buildkit.v1.frontend.LLBBridge.ResolveImageConfig:input_type -> moby.buildkit.v1.frontend.ResolveImageConfigRequest
	15, // 60: moby.buildkit.v1.frontend.LLBBridge.ResolveSourceMeta:input_type -> moby.buildkit.v1.frontend.ResolveSourceMetaRequest
	18, // 61: moby.buildkit.v1.frontend.LLBBridge.Solve:input_type -> moby.buildkit.v1.frontend.SolveRequest
	21, // 62: moby.buildkit.v1.frontend.LLBBridge.ReadFile:input_type -> moby.buildkit.v1.frontend.ReadFileRequest
	24, // 63: moby.buildkit.v1.frontend.LLBBridge.ReadDir:input_type -> moby.buildkit.v1.frontend.ReadDirRequest
	26, // 64: moby.buildkit.v1.frontend.LLBBridge.StatFile:input_type -> moby.buildkit.v1.frontend.StatFileRequest
	28, // 65: moby.buildkit.v1.frontend.LLBBridge.Evaluate:input_type -> moby.buildkit.v1.frontend.EvaluateRequest
	30, // 66: moby.buildkit.v1.frontend.LLBBridge.Ping:input_type -> moby.buildkit.v1.frontend.PingRequest
	9,  // 67: moby.buildkit.v1.frontend.LLBBridge.Return:input_type -> moby.buildkit.v1.frontend.ReturnRequest
	11, // 68: moby.buildkit.v1.frontend.LLBBridge.Inputs:input_type -> moby.buildkit.v1.frontend.InputsRequest
	34, // 69: moby.buildkit.v1.frontend.LLBBridge.NewContainer:input_type -> moby.buildkit.v1.frontend.NewContainerRequest
	36, // 70: moby.buildkit.v1.frontend.LLBBridge.ReleaseContainer:input_type -> moby.buildkit.v1.frontend.ReleaseContainerRequest
	38, // 71: moby.buildkit.v1.frontend.LLBBridge.ExecProcess:input_type -> moby.buildkit.v1.frontend.ExecMessage
	32, // 72: moby.buildkit.v1.frontend.LLBBridge.Warn:input_type -> moby.buildkit.v1.frontend.WarnRequest
	14, // 73: moby.buildkit.v1.frontend.LLBBridge.ResolveImageConfig:output_type -> moby.buildkit.v1.frontend.ResolveImageConfigResponse
	16, // 74: moby.buildkit.v1.frontend.LLBBridge.ResolveSourceMeta:output_type -> moby.buildkit.v1.frontend.ResolveSourceMetaResponse
	20, // 75: moby.buildkit.v1.frontend.LLBBridge.Solve:output_type -> moby.buildkit.v1.frontend.SolveResponse
	23, // 76: moby.buildkit.v1.frontend.LLBBridge.ReadFile:output_type -> moby.buildkit.v1.frontend.ReadFileResponse
	25, // 77: moby.buildkit.v1.frontend.LLBBridge.ReadDir:output_type -> moby.buildkit.v1.frontend.ReadDirResponse
	27, // 78: moby.buildkit.v1.frontend.LLBBridge.StatFile:output_type -> moby.buildkit.v1.frontend.StatFileResponse
	29, // 79: moby.buildkit.v1.frontend.LLBBridge.Evaluate:output_type -> moby.buildkit.v1.frontend.EvaluateResponse
	31, // 80: moby.buildkit.v1.frontend.LLBBridge.Ping:output_type -> moby.buildkit.v1.frontend.PongResponse
	10, // 81: moby.buildkit.v1.frontend.LLBBridge.Return:output_type -> moby.buildkit.v1.frontend.ReturnResponse
	12, // 82: moby.buildkit.v1.frontend.LLBBridge.Inputs:output_type -> moby.buildkit.v1.frontend.InputsResponse
	35, // 83: moby.buildkit.v1.frontend.LLBBridge.NewContainer:output_type -> moby.buildkit.v1.frontend.NewContainerResponse
	37, // 84: moby.buildkit.v1.frontend.LLBBridge.ReleaseContainer:output_type -> moby.buildkit.v1.frontend.ReleaseContainerResponse
	38, // 85: moby.buildkit.v1.frontend.LLBBridge.ExecProcess:output_type -> moby.buildkit.v1.frontend.ExecMessage
	33, // 86: moby.buildkit.v1.frontend.LLBBridge.Warn:output_type -> moby.buildkit.v1.frontend.WarnResponse
	73, // [73:87] is the sub-list for method output_type
	59, // [59:73] is the sub-list for method input_type
	59, // [59:59] is the sub-list for extension type_name
	59, // [59:59] is the sub-list for extension extendee
	0,  // [0:59] is the sub-list for field type_name
}

func init() { file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_init() }
func file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_init() {
	if File_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto != nil {
		return
	}
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[0].OneofWrappers = []any{
		(*Result_RefDeprecated)(nil),
		(*Result_RefsDeprecated)(nil),
		(*Result_Ref)(nil),
		(*Result_Refs)(nil),
	}
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes[36].OneofWrappers = []any{
		(*ExecMessage_Init)(nil),
		(*ExecMessage_File)(nil),
		(*ExecMessage_Resize)(nil),
		(*ExecMessage_Started)(nil),
		(*ExecMessage_Exit)(nil),
		(*ExecMessage_Done)(nil),
		(*ExecMessage_Signal)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDesc), len(file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_rawDesc)),
			NumEnums:      2,
			NumMessages:   53,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_goTypes,
		DependencyIndexes: file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_depIdxs,
		EnumInfos:         file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_enumTypes,
		MessageInfos:      file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_msgTypes,
	}.Build()
	File_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto = out.File
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_goTypes = nil
	file_github_com_moby_buildkit_frontend_gateway_pb_gateway_proto_depIdxs = nil
}
